@@ -29,10 +29,23 @@ class ThroughputTarget(Enum):
     吞吐量目标
     https://ndnsim.net/current/metric.html
     """
-    Packets = 0  # estimated rate (EWMA average) of packets within the last averaging period (number of packets/s)
-    Kilobytes = 1  # estimated rate (EWMA average) within last averaging period (kilobytes/s)
-    PacketRaw = 2  # absolute number of packets within last averaging period (number of packets).
-    KilobytesRaw = 3  # absolute number of kilobytes transferred within the last averaging period (number of packets).
+    # estimated rate (EWMA average) of packets within the last averaging period (number of packets/s)
+    Packets = 0
+
+    # estimated rate (EWMA average) within last averaging period (kilobytes/s)
+    Kilobytes_KBps = 1
+    Kilobytes_MBps = 2
+    Kilobytes_Kbps = 3
+    Kilobytes_Mbps = 4
+
+    # absolute number of packets within last averaging period (number of packets).
+    PacketRaw = 5
+
+    # absolute number of kilobytes transferred within the last averaging period (number of packets).
+    KilobytesRaw_KBps = 6
+    KilobytesRaw_MBps = 7
+    KilobytesRaw_Kbps = 8
+    KilobytesRaw_Mbps = 9
 
 
 class ThroughputItem:
@@ -66,12 +79,24 @@ class ThroughputItem:
     def getValueByThroughputTarget(self, throughputTarget: ThroughputTarget):
         if throughputTarget == ThroughputTarget.Packets:
             return self.Packets
-        elif throughputTarget == ThroughputTarget.Kilobytes:
+        elif throughputTarget == ThroughputTarget.Kilobytes_KBps:
             return self.Kilobytes
+        elif throughputTarget == ThroughputTarget.Kilobytes_MBps:
+            return self.Kilobytes / 1000
+        elif throughputTarget == ThroughputTarget.Kilobytes_Kbps:
+            return self.Kilobytes * 8
+        elif throughputTarget == ThroughputTarget.Kilobytes_Mbps:
+            return self.Kilobytes * 8 / 1000
         elif throughputTarget == ThroughputTarget.PacketRaw:
             return self.PacketRaw
-        else:
+        elif throughputTarget == ThroughputTarget.KilobytesRaw_KBps:
             return self.KilobytesRaw
+        elif throughputTarget == ThroughputTarget.KilobytesRaw_MBps:
+            return self.KilobytesRaw / 1000
+        elif throughputTarget == ThroughputTarget.KilobytesRaw_Kbps:
+            return self.KilobytesRaw * 8
+        elif throughputTarget == ThroughputTarget.KilobytesRaw_Mbps:
+            return self.KilobytesRaw * 8 / 1000
 
     @staticmethod
     def parseLine(line: str):
@@ -131,7 +156,7 @@ class NodeFaceThroughput:
         return res
 
     def getY(self, throughputType: ThroughputType = ThroughputType.OutData,
-             throughputTarget: ThroughputTarget = ThroughputTarget.Kilobytes,
+             throughputTarget: ThroughputTarget = ThroughputTarget.Kilobytes_KBps,
              samplingInterval: float = 1.0):
         """
         获取吞吐量列表
@@ -186,7 +211,7 @@ class NodeThroughput:
         return self.faceIdMap[FaceId].getX(throughputType, samplingInterval)
 
     def getY(self, FaceId: int, throughputType: ThroughputType = ThroughputType.OutData,
-             throughputTarget: ThroughputTarget = ThroughputTarget.Kilobytes, samplingInterval: float = 1.0):
+             throughputTarget: ThroughputTarget = ThroughputTarget.Kilobytes_KBps, samplingInterval: float = 1.0):
         """
         获取吞吐量列表
         :param FaceId:                  FaceId
@@ -249,7 +274,7 @@ class ThroughputGraph(GraphBase):
         self.throughput = throughput
         self.samplingInterval = 1.0
         self.throughputType = ThroughputType.OutData
-        self.throughputTarget = ThroughputTarget.Kilobytes
+        self.throughputTarget = ThroughputTarget.Kilobytes_KBps
 
     def setSamplingInterval(self, samplingInterval: float):
         """
@@ -286,7 +311,7 @@ class ThroughputGraph(GraphBase):
         node = self.throughput.getByNode(node)
         if not node:
             print("not exist node: ", node)
-            return
+            return self
         if "label" not in kwargs:
             kwargs["label"] = node.Node
         x, y = node.getX(faceId, samplingInterval=self.samplingInterval), \
